"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.emitOne = exports.emitMany = void 0;
const Keywords = require("../tokens/keywords");
const Delimiters = require("../tokens/delimiters");
const NamespaceTokens = require("../tokens/namespace_tokens");
const ScopeTokens = require("../tokens/scope_tokens");
const StructEmitter = require("./struct_emitter");
const ClassEmitter = require("./class_emitter");
const NamespaceImportEmitter = require("./namespace_import_emitter");
function emitMany(writer, namespaces) {
    if (namespaces == null || namespaces.length === 0)
        return;
    namespaces.forEach(ns => emitOne(writer, ns));
}
exports.emitMany = emitMany;
function emitOne(writer, namespace) {
    const { path, imports, structs, classes } = namespace;
    emitDefinition(writer, path);
    imports && NamespaceImportEmitter.emitMany(writer, imports);
    structs && StructEmitter.emitMany(writer, structs);
    classes && ClassEmitter.emitMany(writer, classes, (structs == null || structs.length === 0));
    emitEnd(writer);
}
exports.emitOne = emitOne;
function emitDefinition(writer, path) {
    writer
        .writeLine(Keywords.namespace, Delimiters.space, ...NamespaceTokens.emit(path))
        .writeLine(ScopeTokens.open)
        .indent();
}
function emitEnd(writer) {
    writer
        .unindent()
        .writeLine(ScopeTokens.close)
        .writeLine();
}
