"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.IndentedStringWriter = void 0;
class IndentedStringWriter {
    constructor(indentSize = 2) {
        this._buffer = [];
        this._indentLevel = 0;
        this._offset = "";
        this._eol = "\r\n";
        this._indentSize = indentSize;
    }
    get indentLevel() {
        return this._indentLevel;
    }
    set indentLevel(value) {
        this._indentLevel = value < 0 ? 0 : value;
        this._offset = " ".repeat(this._indentLevel * this._indentSize);
    }
    get buffer() {
        return this._buffer;
    }
    outputTabs() {
        this._buffer.push(this._offset);
        return this;
    }
    writeLine(...values) {
        this._buffer.push(this._offset);
        values.forEach(v => this._buffer.push(v));
        this._buffer.push(this._eol);
        return this;
    }
    writeLineNoTabs(...values) {
        values.forEach(v => this._buffer.push(v));
        this._buffer.push(this._eol);
        return this;
    }
    write(...values) {
        values.forEach(v => this._buffer.push(v));
        return this;
    }
    indent() {
        this.indentLevel++;
        return this;
    }
    unindent() {
        this.indentLevel--;
        return this;
    }
    toString() {
        return this._buffer.join("");
    }
}
exports.IndentedStringWriter = IndentedStringWriter;
